@@ -1,7 +1,7 @@
 from typing import List
+from dataclasses import dataclass
 from enum import Enum
 from typing import Union
-from dataclasses import dataclass
 
 
 class ActivationsEnum(Enum):
@@ -207,7 +207,6 @@ class NodeType(Enum):
     CustomLayer = "CustomLayer"
     CustomLoss = "CustomLoss"
     Visualizer = "Visualizer"
-    Metric = "Metric"
     Lambda = "Lambda"
     TFOpLambda = "TFOpLambda"
     SlicingOpLambda = "SlicingOpLambda"
@@ -1706,11 +1705,6 @@ class Visualizer:
     type: NodeType
 
 
-@dataclass
-class Metric:
-    type: NodeType
-
-
 @dataclass
 class Lambda:
     type: NodeType
@@ -1774,5 +1768,4 @@ class NodeDataTypes:
                  MeanAbsoluteError, MeanAbsolutePercentageError, MeanSquaredError, MeanSquaredLogarithmicError, Poisson, 
                  SquaredHinge, Adadelta, Adagrad, Adam, Adamax, Ftrl, Nadam, RMSprop, SGD, OnnxAbs, OnnxErf, 
                  OnnxHardSigmoid, OnnxReduceMean, OnnxSqrt, Dataset, RepresentationBlock, GroundTruth, CustomLayer, 
-                 CustomLoss, Visualizer, Metric, Lambda, TFOpLambda, SlicingOpLambda, Repeat, Variable, Gather, 
-                 FixedDropout]
+                 CustomLoss, Visualizer, Lambda, TFOpLambda, SlicingOpLambda, Repeat, Variable, Gather, FixedDropout]
