@@ -98,6 +98,8 @@ class KerasJsonModelImport:
         if len(inbound_nodes) == 0:
             return
         inbound_nodes_to_enumerate = inbound_nodes[instance_index]
+        if isinstance(inbound_nodes_to_enumerate, dict):
+            inbound_nodes_to_enumerate = list(inbound_nodes_to_enumerate.values())
         if isinstance(inbound_nodes_to_enumerate[0], list):
             inbound_nodes_to_enumerate_prepared = []
             for inbound_node in inbound_nodes_to_enumerate:
@@ -184,7 +186,7 @@ class KerasJsonModelImport:
 
     def generate_regular_node(self, layer: Dict[str, Any], layer_metadata: Dict[str, Any], node_key: str):
         data = layer['config']
-        if layer['class_name'] in ('TFOpLambda', 'SlicingOpLambda'):
+        if layer['class_name'] in ('TFOpLambda', 'SlicingOpLambda') or layer['class_name'] in self.custom_layers:
             data['inbound_nodes'] = layer['inbound_nodes'][0]
         elif layer['class_name'] == "Lambda":
             lambda_func = func_load(layer['config']['function'])
